Stan Math Library: stan::math::promoter< std::vector< T >, std::vector< T > > Struct Template Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- Class List
- Class Index
- Class Hierarchy
- Class Members

Static Public Member Functions | List of all members
stan::math::promoter< std::vector< T >, std::vector< T > > Struct Template Reference

`#include <promoter.hpp>`

## Static Public Member Functions
static void | promote (const std::vector< T > &u, std::vector< T > &t)
static std::vector< T > | promote_to (const std::vector< T > &u)

## Detailed Description

### template<typename T>
struct stan::math::promoter< std::vector< T >, std::vector< T > >

Definition at line 51 of file promoter.hpp.

## Member Function Documentation

template<typename T >

static void stan::math::promoter< std::vector< T >, std::vector< T > >::promote | ( | const std::vector< T > & | u,
|  | std::vector< T > & | t
| ) |  |
| inlinestatic

Definition at line 52 of file promoter.hpp.

template<typename T >

static std::vector<T> stan::math::promoter< std::vector< T >, std::vector< T > >::promote_to | ( | const std::vector< T > & | u | ) |
| inlinestatic

Definition at line 56 of file promoter.hpp.

The documentation for this struct was generated from the following file:

- stan/math/prim/mat/fun/promoter.hpp

[ Stan Home Page ] © 2011–2016, Stan Development Team.